<?php

declare(strict_types=1);

namespace Drupal\eplikt;

use Drupal\Component\Plugin\PluginBase;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * A base class to help developers implement their own e-Plikt source plugins.
 *
 * @see \Drupal\eplikt\Annotation\EpliktSource
 * @see \Drupal\eplikt\EpliktSourceInterface
 */
abstract class EpliktSourceBase extends PluginBase implements EpliktSourceInterface {

  use StringTranslationTrait;

  /**
   * The plugin ID of this e-Plikt source plugin.
   *
   * @var string
   */
  protected $pluginId;

  /**
   * The name of the provider that owns this e-Plikt source plugin.
   *
   * @var string
   */
  public string $provider;

  /**
   * An associative array containing the configuration for this e-Plikt source plugin.
   *
   * @var array
   */
  public $settings = [];

  /**
   * EpliktSourceBase constructor.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->provider = $this->pluginDefinition['provider'];
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getLabel(): string {
    return (string) $this->pluginDefinition['label'];
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription(): string {
    return (string) $this->pluginDefinition['description'];
  }

  /**
   * {@inheritdoc}
   */
  public function getConfiguration() {
    return $this->configuration;
  }

  /**
   * {@inheritdoc}
   */
  public function setConfiguration(array $configuration) {
    $this->configuration = $configuration;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'id' => $this->getPluginId(),
      'provider' => $this->pluginDefinition['provider'],
    ];
  }

}
